@@ -74,6 +74,7 @@ class CGSmartImage extends CGExtensions
     $this->SetParameterType(CLEAN_REGEXP.'/src\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/alias\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/filter_\w*/',CLEAN_STRING);
+    $this->SetParameterType('silent',CLEAN_INT);
 
     // more smarty plugins
     $smarty = cmsms()->GetSmarty();
@@ -82,6 +83,7 @@ class CGSmartImage extends CGExtensions
 
   function InitializeAdmin()
   {
+    $this->CreateParameter('silent','',$this->Lang('param_silent'));
     $this->CreateParameter('alias','',$this->Lang('param_alias'));
     $this->CreateParameter('noautoscale','',$this->Lang('param_noautoscale'));
     $this->CreateParameter('nobcache','',$this->Lang('param_nobcache'));
@@ -126,7 +128,7 @@ class CGSmartImage extends CGExtensions
   }
 
   function LazyLoadAdmin() { return TRUE; }
-  function LazyLoadFrontend() { return TRUE; }
+  function LazyLoadFrontend() { return FALSE; }
 
   /*---------------------------------------------------------
    GetName()
@@ -151,7 +153,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.7.1';
+    return '1.8.1';
   }
 
   
@@ -371,9 +373,9 @@ class CGSmartImage extends CGExtensions
       }
 	  
     $thedate = time() - $age_days * 24 * 60 * 60;
+    $n_removed = 0;
     if( $dh = opendir($dir) ) 
       {
-	$n_removed = 0;
 	while( ($file = readdir($dh)) !== false )
 	  {
 	    if( startswith($file,'.') ) continue; // ignore hidden files.
