@@ -43,7 +43,7 @@ if( isset($params['submit']) )
     $this->SetPreference('croptofit_default_loc',trim($params['croptofit_default_loc']));
     $this->SetPreference('cache_age',(int)$params['cache_age']);
     $this->SetPreference('image_url_prefix',trim($params['image_url_prefix']));
-    $this->SetPreference('image_url_hascachedir',(int)$params['image_url_hascachedir']);
+    $this->SetPreference('image_url_hascachedir',(isset($params['image_url_hascahedir']))?(int)$params['image_url_hascachedir']:0);
     $this->SetMessage($this->Lang('msg_prefsupdated'));
   }
 else if( isset($params['clear_now']) )
