@@ -42,7 +42,7 @@ class CGImageBase implements ArrayAccess
   private $_srcname;
   private $_dirty;
   private $_info;
-  private static $_keys = array('rsrc','width','height','type','filename','name','transparent');
+  private static $_keys = array('dirty','rsrc','width','height','type','filename','name','transparent');
 
   private function create_new_rsrc($mimetype,$width,$height)
   {
