@@ -39,10 +39,14 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
 {
   private $_dest_w = 0;
   private $_dest_h = 0;
+  private $_loc = 'c';
+  static private $_valid_locs = array('tl','tc','tr','cl','c','cr','bl','bc','br');
 
     
   public function __construct($input)
   {
+    $mod = cms_utils::get_module('CGSmartImage');
+    $this->_loc = $mod->GetPreference('croptofit_default_loc','c');
     if( cge_array::is_hash($input) )
       {
 	if( isset($input['width']) )
@@ -55,13 +59,21 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
 	    $this->_dest_w = (int)$input['w'];
 	    $this->_dest_h = (int)$input['h'];
 	  }
+	if( isset($input['loc']) && in_array($input['loc'],self::$_valid_locs) )
+	  {
+	    $this->_loc = $input['loc'];
+	  }
       }
     else if( is_array($input)  )
       {
-	if( count($input) == 2 )
+	if( count($input) >= 2 )
 	  {
 	    $this->_dest_w = (int)trim($input[0]);
 	    $this->_dest_h = (int)trim($input[1]);
+	    if( count($input) >= 3 && in_array($input[2],self::$_valid_locs) )
+	      {
+		$this->_loc = $input[2];
+	      }
 	  }
       }
 
@@ -74,6 +86,17 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
 
   public function transform(CGImageBase $src)
   {
+    // prevent any upscaling
+    $this->_dest_w = min($this->_dest_w,$src['width']);
+    $this->_dest_h = min($this->_dest_h,$src['height']);
+
+    // quick optimization (nothing to do)
+    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] )
+      {
+	//$src['width'] = $src['width'];
+	return $src;
+      }
+
     //
     // note:  this code developed by using the following page as a reference
     // http://911-need-code-help.blogspot.com/2009/04/crop-to-fit-image-using-aspphp.html
@@ -81,7 +104,6 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     $src_ratio = (float)$src['width'] / (float)$src['height'];
     $dest_ratio = (float)$this->_dest_w / (float)$this->_dest_h;
 
-
     // determine the size of the temp image that fits into
     // the desired area by at least one dimension.
     $new_h = '';
@@ -124,8 +146,55 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
       }
 
     // calculate the offset into the destination iamge.
-    $x0 = (int)( $this->_dest_w - $new_w ) / 2;
-    $y0 = (int)( $this->_dest_h - $new_h ) / 2;
+    switch( $this->_loc )
+      {
+      case 'tl':
+	$x0 = 0;
+	$y0 = 0;
+	break;
+
+      case 'tc':
+	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
+	$y0 = 0;
+	break;
+
+      case 'tr':
+	$x0 = (int)( $new_w - $this->_dest_w );
+	$y0 = 0;
+	break;
+
+      case 'cl':
+	$x0 = 0;
+	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
+	break;
+
+      case 'cr':
+	$x0 = (int)( $new_w - $this->_dest_w );
+	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
+	break;
+
+      case 'bl':
+	$x0 = 0;
+	$y0 = (int)( $new_h - $this->_dest_h );
+	break;
+
+      case 'bc':
+	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
+	$y0 = (int)( $new_h - $this->_dest_h );
+	break;
+
+      case 'br':
+	$x0 = (int)( $new_w - $this->_dest_w );
+	$y0 = (int)( $new_h - $this->_dest_h );
+	break;
+
+      case 'c':
+      default:
+	// center
+	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
+	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
+	break;
+      }
 
     // create destination image at the desired thumb size.
     $_dest = new CGImageBase(array($src['type'],$this->_dest_w,$this->_dest_h));
@@ -138,7 +207,7 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     // copy the temp iamge into the dest image.
     imagealphablending($_dest['rsrc'],TRUE);
     
-    $res = imagecopy($_dest['rsrc'],$tmp_rsrc,$x0,$y0,0,0,$new_w,$new_h);
+    $res = imagecopy($_dest['rsrc'],$tmp_rsrc,0,0,$x0,$y0,$new_w,$new_h);
     //$res = imagecopymerge($_dest['rsrc'],$tmp_rsrc,$x0,$y0,0,0,$new_w,$new_h,100); works.
     if( $res === FALSE )
       {
