@@ -39,6 +39,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 {
   private $_width;         // dest width
   private $_height;        // dest height
+  private $_edge = 0;	   //edge size
   private $_percent = 0;   // scale to percent
   private $_resample = 1;  // resample, vs resize.
 
@@ -83,6 +84,8 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 	  case 'h':
 	    $this->_height = (int)$input[1];
 	    break;
+	  case 'e':
+	    $this->_edge = (int)$input[1];
 	  case 'c':
 	    $this->_width = (int)$input[1];
 	    $this->_height = (int)$input[2];
@@ -90,7 +93,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 	  }
       }
 
-    if( !($this->_percent > 0 || $this->_width > 0 || $this->_height > 0) )
+    if( !($this->_percent > 0 || $this->_width > 0 || $this->_height > 0 || $this->_edge > 0) )
       {
 	throw new Exception('Could not Create Resize Filter - Invalid Parameters');
       }
@@ -133,7 +136,6 @@ class CGImage_Resize_Filter extends CGImageFilterBase
     return $this->_transform($src,$new_w,$new_h);
   }
 
-
   protected function _transform_height(CGImageBase $src)
   {
     // calculate new width and height, preserving aspect ratio
@@ -142,6 +144,20 @@ class CGImage_Resize_Filter extends CGImageFilterBase
     return $this->_transform($src,$new_w,$new_h);
   }
 
+  protected function _transform_edge(CGImageBase $src)
+  {
+    //find the longest edge of image and resize based on it
+    if($src['width'] > $src['height']){
+        $new_w = $this->_edge;
+        $new_h = (int)($this->_edge * $src['height'] / $src['width']);
+        return $this->_transform($src,$new_w,$new_h);
+
+    }else{
+        $new_h = $this->_edge;
+        $new_w = (int)($this->_edge * $src['width'] / $src['height']);
+        return $this->_transform($src,$new_w,$new_h);
+    }
+  }
   
   protected function _transform_custom(CGImageBase $src)
   {
@@ -159,6 +175,10 @@ class CGImage_Resize_Filter extends CGImageFilterBase
 	// percentage resize.
 	return $this->_transform_percentage($img);
       }
+      if($this->_edge > 0 && ($img['width'] > $this->_edge || $img['height'] > $this->_edge)){
+      //resize by longest edge
+       return $this->_transform_edge($img);
+      }
     if( $this->_width > 0 && $this->_height == 0 && $img['width'] > $this->_width )
       { 
 	return $this->_transform_width($img);
