@@ -603,7 +603,7 @@ class cgsi_utils
     // build the output.
     if( $opp['notag'] || self::_is_stylesheet() )
       {
-	$outp['src'] = $dest['url'];
+	$outp['src'] = $dest_url;
 	if( !$opp['noembed'] && $mod->can_embed($dest_fname) )
 	  {
 	    $type = cge_utils::get_mime_type($dest_fname);
